#region Using

using System;
using System.Web;

using Sitecore;
using Sitecore.Globalization;
using Sitecore.Data;
using Sitecore.Data.Items;
using Sitecore.Web.UI.Framework;
using Sitecore.Web.UI.Sheer;
using Sitecore.Web.UI.HtmlControls;

#endregion

namespace FirstXamlExample
{
	public class XmlPlaygroundForm : Sitecore.Web.UI.Sheer.BaseForm
	{
      protected Edit Edit;
      protected Button BesideButton;

      // String property that is persisted across postbacks using the ServerProperties StateBag.
      protected string PersistentValue
      {
         get 
         {
            return Context.ClientPage.ServerProperties["PersistentValue"] as string;
         }
         set 
         {
            Context.ClientPage.ServerProperties["PersistentValue"] = value;
            Edit.Value = value;
         }
      }

      public XmlPlaygroundForm()
      {
      }

      // OnLoad method is fired when the form is loading, similar to the asp.net
      protected override void OnLoad(EventArgs args)
      {
         // This is how you can determine whether application is just launching
         // or handling postback, similar to the Page.IsPostBack in asp.net
         if (!Context.ClientPage.IsEvent)
         {
            PersistentValue = "Initial";
         }

         // Subscribe to the OnClick event of the BesideButton
         BesideButton.OnClick += new EventHandler(BesideButton_OnClick);
      }

      // Shows method invocation
      // Invoked by <Button Click="OnMethodButton" />
      protected void OnMethodButton()
      {
         Edit.Value = "OnMethodButton handler";
      }

      // Shows message handling
      // Catches the message sent by <Button Click="playground:messagebutton" />
      [HandleMessage("playground:messagebutton")]
      protected void MessageButton(Message message)
      {
         Edit.Value = "playground:messagebutton handler";
      }

      // Regular event hanling technique
      // Handles the Click event of BesideButton
      private void BesideButton_OnClick(object sender, EventArgs e)
      {
         Edit.Value = "BesideButton_OnClick handler";
      }

      // Appends current Edit value to the previous persisted one
      protected void OnAppend()
      {
         PersistentValue = PersistentValue + "|" + Edit.Value;
      }

      // Clears the persisted value
      protected void OnClear()
      {         
         PersistentValue = string.Empty;
      }
   }
}
